# ----------------------------------------------------------------------------------------------------------------------
# - Package Imports -
# ----------------------------------------------------------------------------------------------------------------------
# General Packages
from __future__ import annotations
from abc import ABC, abstractmethod

# Custom Library

# Custom Packages

# ----------------------------------------------------------------------------------------------------------------------
# - Code -
# ----------------------------------------------------------------------------------------------------------------------
class CSSPropertyShorthand(ABC):
    short_name:str
    # ------------------------------------------------------------------------------------------------------------------
    # - Generator -
    # ------------------------------------------------------------------------------------------------------------------
    def name_printer(self) -> str:
        return f"{self.short_name}"

    @abstractmethod
    def value_printer(self) -> str:...

    def printer(self) -> str:
        return f"{self.name_printer()}: {self.value_printer()}"

    def __str__(self) -> str:
        return self.printer()